==> PPDF_1_3_1.zip: PubMedPDF/pdf_add.php <==
<?php
	include "../../mainfile.php";
	include "style.php";
	include "include/conn.php";
	
	if ( file_exists("language/".$xoopsConfig['language']."/main.php") ) {
		include "language/".$xoopsConfig['language']."/main.php";
	} else {
		include "language/english/main.php";
	}
	
	if($id = intval(@$_GET["id"])){
	
		echo "<div class=\"pt\">"._MD_PDF_A."</div>";
		echo "<div class=\"pc\">";
		echo "<form enctype=\"multipart/form-data\" action=\"".$_SERVER[PHP_SELF]."\" method=\"POST\">";
		echo "<input type=\"file\" name=\"userfile\">";
		echo "<input type=\"submit\" name=\"upload\" value=\"submit\">";
		echo "<input type=\"hidden\" name=\"id\" value=\"".$id."\">";
		echo "</form></div>";
	}
	
	if(@$_POST["upload"]){
		$id = intval(@$_POST["id"]);
	
		# upload directory(relative pass)
		$sql = "SELECT * FROM ".$T_CONFIG." WHERE conf_name='updir'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$up_pass = $row["conf_value"];

		if(substr($up_pass,-1) != "/") $up_pass.="/";
		if(!is_dir($up_pass))	$rc = mkdir($up_pass, 0777);

		if(is_uploaded_file($_FILES['userfile']['tmp_name'])){
			$file_name = $_FILES['userfile']['name'];

			if(preg_match("/.*(\.pdf)$/i", $file_name)){
				copy($_FILES['userfile']['tmp_name'], $up_pass.$id.".pdf");
				echo "File upload has done.";

			}else{
				echo "error: This isn't PDF file.<br>";
			}
		}else{
			echo "error: File upload failed.<br>";
		}

		echo <<<E
		<script>
		 window.opener.location.reload();
		 setTimeout('window.close()', 1200);
		</script>
E;

	}

?>

==> PPDF_1_4.zip: PubMedPDF/pdf_add.php <==
<?php
	include "../../mainfile.php";
	include "style.php";
	include "include/conn.php";
	
	if ( file_exists("language/".$xoopsConfig['language']."/main.php") ) {
		include "language/".$xoopsConfig['language']."/main.php";
	} else {
		include "language/english/main.php";
	}
	
	if($id = intval(@$_GET["id"])){
	
		echo "<div class=\"pt\">"._MD_PDF_A."</div>";
		echo "<div class=\"pc\">";
		echo "<form enctype=\"multipart/form-data\" action=\"".$_SERVER[PHP_SELF]."\" method=\"POST\">";
		echo "<input type=\"file\" name=\"userfile\">";
		echo "<input type=\"submit\" name=\"upload\" value=\"submit\">";
		echo "<input type=\"hidden\" name=\"id\" value=\"".$id."\">";
		echo "</form></div>";
	}
	
	if(@$_POST["upload"]){
		$id = intval(@$_POST["id"]);
	
		# upload directory(relative pass)
		$sql = "SELECT * FROM ".$T_CONFIG." WHERE conf_name='updir'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);
		$up_pass = $row["conf_value"];

		if(substr($up_pass,-1) != "/") $up_pass.="/";
		if(!is_dir($up_pass))	$rc = mkdir($up_pass, 0777);

		if(is_uploaded_file($_FILES['userfile']['tmp_name'])){
			$file_name = $_FILES['userfile']['name'];

			if(preg_match("/.*(\.pdf)$/i", $file_name)){
				copy($_FILES['userfile']['tmp_name'], $up_pass.$id.".pdf");
				echo "File upload has been completed.";

			}else{
				echo "error: This isn't PDF file.<br>";
			}
		}else{
			echo "error: File upload failed.<br>";
		}

		echo <<<E
		<script>
		 window.opener.location.reload();
		 setTimeout('window.close()', 1200);
		</script>
E;

	}

?>
